Conversion functions
=================================

.. autoclass:: tomni.annotation_manager.main.AnnotationManager
   :members: to_dict, to_binary_mask, to_labeled_mask, to_contours
   :show-inheritance:

